@@ -144,7 +144,7 @@ static gboolean irc_free_hashkey( gpointer key, gpointer value, gpointer data )
 /* Because we have no garbage collection, this is quite annoying */
 void irc_free(irc_t * irc)
 {
-	account_t *account, *accounttmp;
+	account_t *account;
 	user_t *user, *usertmp;
 	nick_t *nick, *nicktmp;
 	help_t *helpnode, *helpnodetmp;
@@ -189,17 +189,13 @@ void irc_free(irc_t * irc)
 	while (irc->queries != NULL)
 		query_del(irc, irc->queries);
 	
-	if (irc->accounts != NULL) {
-		account = irc->accounts;
-		while (account != NULL) {
-			g_free(account->user);
-			g_free(account->pass);
-			g_free(account->server);
-			accounttmp = account;
-			account = account->next;
-			g_free(accounttmp);
-		}
-	}
+	while (irc->accounts)
+		if (irc->accounts->gc == NULL)
+			account_del(irc, irc->accounts);
+		else
+			/* Nasty hack, but account_del() doesn't work in this
+			   case and we don't want infinite loops, do we? ;-) */
+			irc->accounts = irc->accounts->next;
 	
 	if (irc->users != NULL) {
 		user = irc->users;
